@@ -285,7 +285,7 @@ class ProvisionProductTask(ProvisioningTask, manifest_tasks.ManifestMixen):
 
                 if need_to_provision:
                     self.info(
-                        f"about to provision with params: {json.dumps(params_to_use)}"
+                        f"about to provision with params: {json.dumps(tasks.unwrap(params_to_use))}"
                     )
 
                     if provisioned_product_id:
@@ -469,7 +469,7 @@ class ProvisionProductDryRunTask(ProvisionProductTask):
             )
 
             provisioned_product_id = False
-            provisioning_artifact_id = False
+            provisioning_artifact_id = None
             current_status = "NOT_PROVISIONED"
             for r in response.get("ProvisionedProducts", []):
                 if r.get("Name") == self.launch_name:
@@ -478,80 +478,91 @@ class ProvisionProductDryRunTask(ProvisionProductTask):
                         provisioned_product_id = r.get("Id")
                         provisioning_artifact_id = r.get("ProvisioningArtifactId")
 
-            self.info(
-                f"pp_id: {provisioned_product_id}, paid : {provisioning_artifact_id}"
-            )
-            current_version_details = self.get_current_version(
-                provisioning_artifact_id, service_catalog
-            )
-
-            with betterboto_client.CrossAccountClientContextManager(
-                "cloudformation",
-                role,
-                f"cfn-{self.region}-{self.account_id}",
-                region_name=self.region,
-            ) as cloudformation:
+            if provisioning_artifact_id is None:
+                self.info(f"params unchanged")
+                self.write_result(
+                    current_version="-",
+                    new_version=self.version,
+                    effect=constants.CHANGE,
+                    current_status="NOT_PROVISIONED",
+                    active="N/A",
+                    notes="New provisioning",
+                )
+            else:
                 self.info(
-                    f"running as {role},checking {self.product_id} {self.version_id} {path_id} in {self.account_id} {self.region}"
+                    f"pp_id: {provisioned_product_id}, paid : {provisioning_artifact_id}"
+                )
+                current_version_details = self.get_current_version(
+                    provisioning_artifact_id, service_catalog
                 )
 
-                with self.input().get("provisioning_artifact_parameters").open(
-                    "r"
-                ) as f:
-                    provisioning_artifact_parameters = json.loads(f.read())
-
-                params_to_use = {}
-                for p in provisioning_artifact_parameters:
-                    param_name = p.get("ParameterKey")
-                    params_to_use[param_name] = all_params.get(
-                        param_name, p.get("DefaultValue")
+                with betterboto_client.CrossAccountClientContextManager(
+                    "cloudformation",
+                    role,
+                    f"cfn-{self.region}-{self.account_id}",
+                    region_name=self.region,
+                ) as cloudformation:
+                    self.info(
+                        f"running as {role},checking {self.product_id} {self.version_id} {path_id} in {self.account_id} {self.region}"
                     )
 
-                if provisioning_artifact_id == self.version_id:
-                    self.info(f"found previous good provision")
-                    if provisioned_product_id:
-                        self.info(f"checking params for diffs")
-                        provisioned_parameters = aws.get_parameters_for_stack(
-                            cloudformation,
-                            f"SC-{self.account_id}-{provisioned_product_id}",
+                    with self.input().get("provisioning_artifact_parameters").open(
+                        "r"
+                    ) as f:
+                        provisioning_artifact_parameters = json.loads(f.read())
+
+                    params_to_use = {}
+                    for p in provisioning_artifact_parameters:
+                        param_name = p.get("ParameterKey")
+                        params_to_use[param_name] = all_params.get(
+                            param_name, p.get("DefaultValue")
                         )
-                        self.info(f"current params: {provisioned_parameters}")
-                        self.info(f"new params: {params_to_use}")
 
-                        if provisioned_parameters == params_to_use:
-                            self.info(f"params unchanged")
-                            self.write_result(
-                                current_version=self.version,
-                                new_version=self.version,
-                                effect=constants.NO_CHANGE,
-                                current_status=current_status,
-                                active=current_version_details.get("Active"),
-                                notes="Versions and params are the same",
+                    if provisioning_artifact_id == self.version_id:
+                        self.info(f"found previous good provision")
+                        if provisioned_product_id:
+                            self.info(f"checking params for diffs")
+                            provisioned_parameters = aws.get_parameters_for_stack(
+                                cloudformation,
+                                f"SC-{self.account_id}-{provisioned_product_id}",
                             )
-                        else:
-                            self.write_result(
-                                current_version=self.version,
-                                new_version=self.version,
-                                effect=constants.CHANGE,
-                                current_status=current_status,
-                                active=current_version_details.get("Active"),
-                                notes="Versions are the same but the params are different",
-                            )
-                else:
-                    if provisioning_artifact_id:
-                        current_version = current_version_details.get("Name")
-                        active = current_version_details.get("Active")
+                            self.info(f"current params: {provisioned_parameters}")
+                            self.info(f"new params: {params_to_use}")
+
+                            if provisioned_parameters == params_to_use:
+                                self.info(f"params unchanged")
+                                self.write_result(
+                                    current_version=self.version,
+                                    new_version=self.version,
+                                    effect=constants.NO_CHANGE,
+                                    current_status=current_status,
+                                    active=current_version_details.get("Active"),
+                                    notes="Versions and params are the same",
+                                )
+                            else:
+                                self.write_result(
+                                    current_version=self.version,
+                                    new_version=self.version,
+                                    effect=constants.CHANGE,
+                                    current_status=current_status,
+                                    active=current_version_details.get("Active"),
+                                    notes="Versions are the same but the params are different",
+                                )
                     else:
-                        current_version = ""
-                        active = False
-                    self.write_result(
-                        current_version=current_version,
-                        new_version=self.version,
-                        effect=constants.CHANGE,
-                        current_status=current_status,
-                        active=active,
-                        notes="Version change",
-                    )
+                        if provisioning_artifact_id:
+                            current_version = current_version_details.get("Name")
+                            active = current_version_details.get("Active")
+                        else:
+                            current_version = ""
+                            active = False
+                        self.write_result(
+                            current_version=current_version,
+                            new_version=self.version,
+                            effect=constants.CHANGE,
+                            current_status=current_status,
+                            active=active,
+                            notes="Version change",
+                        )
 
     def get_current_version(self, provisioning_artifact_id, service_catalog):
         return service_catalog.describe_provisioning_artifact(
